Nohara Hiroshi. Hiru Meshi no Ryuugi - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# Nohara Hiroshi. Hiru Meshi no Ryuugi

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/Nohara%20Hiroshi.%20Hiru%20Meshi%20no%20Ryuugi/%5Bshincaps%5D%20Nohara%20Hiroshi%20Hiru%20Meshi%20no%20Ryuugi%20-%2010%20%28BS-EX%201440x1080%20MPEG2%20AAC%29.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/Nohara%20Hiroshi.%20Hiru%20Meshi%20no%20Ryuugi/%5Bshincaps%5D%20Nohara%20Hiroshi%20Hiru%20Meshi%20no%20Ryuugi%20-%2011%20%28BS-EX%201440x1080%20MPEG2%20AAC%29.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | [shincaps] Nohara Hiroshi Hiru Meshi no Ryuugi - 10 (BS-EX 1440x1080 MPEG2 AAC).srt | 3.00 B | 31 Dec 2025 14:50:52
2 | [shincaps] Nohara Hiroshi Hiru Meshi no Ryuugi - 11 (BS-EX 1440x1080 MPEG2 AAC).srt | 3.00 B | 31 Dec 2025 14:50:59

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/Nohara%20Hiroshi.%20Hiru%20Meshi%20no%20Ryuugi/%5Bshincaps%5D%20Nohara%20Hiroshi%20Hiru%20Meshi%20no%20Ryuugi%20-%2011%20%28BS-EX%201440x1080%20MPEG2%20AAC%29.ass'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | [shincaps] Nohara Hiroshi Hiru Meshi no Ryuugi - 11 (BS-EX 1440x1080 MPEG2 AAC).ass | 6.00 B | 31 Dec 2025 14:50:55

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/Nohara%20Hiroshi.%20Hiru%20Meshi%20no%20Ryuugi/%5Bshincaps%5D%20Nohara%20Hiroshi%20Hiru%20Meshi%20no%20Ryuugi%20-%2010%20%28BS-EX%201440x1080%20MPEG2%20AAC%29.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/Nohara%20Hiroshi.%20Hiru%20Meshi%20no%20Ryuugi/%5Bshincaps%5D%20Nohara%20Hiroshi%20Hiru%20Meshi%20no%20Ryuugi%20-%2011%20%28BS-EX%201440x1080%20MPEG2%20AAC%29.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/Nohara%20Hiroshi.%20Hiru%20Meshi%20no%20Ryuugi/%5Bshincaps%5D%20Nohara%20Hiroshi%20Hiru%20Meshi%20no%20Ryuugi%20-%2011%20%28BS-EX%201440x1080%20MPEG2%20AAC%29.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | [shincaps] Nohara Hiroshi Hiru Meshi no Ryuugi - 10 (BS-EX 1440x1080 MPEG2 AAC).srt | 3.00 B | 31 Dec 2025 14:50:52
2 | [shincaps] Nohara Hiroshi Hiru Meshi no Ryuugi - 11 (BS-EX 1440x1080 MPEG2 AAC).ass | 6.00 B | 31 Dec 2025 14:50:55
3 | [shincaps] Nohara Hiroshi Hiru Meshi no Ryuugi - 11 (BS-EX 1440x1080 MPEG2 AAC).srt | 3.00 B | 31 Dec 2025 14:50:59

Upload new files — Search MAL — Back to Index